@@ -1680,13 +1680,12 @@ necessary, since type inference may take arbitrarily long to converge.")
               ;;                                  *compile-object*)
               (let ((code-coverage-records
                       (code-coverage-records (coverage-metadata *compilation*))))
-                  (unless (zerop (hash-table-count code-coverage-records))
-                    ;; Dump the code coverage records into the fasl.
-                    (dump-code-coverage-records
-                     (namestring *compile-file-pathname*)
-                     (loop for k being each hash-key of code-coverage-records
-                           collect (cons k +code-coverage-unmarked+))
-                     *compile-object*)))
+                (unless (zerop (hash-table-count code-coverage-records))
+                  ;; Dump the code coverage records into the fasl.
+                  (dump-code-coverage-records
+                   (loop for k being each hash-key of code-coverage-records
+                         collect k)
+                   *compile-object*)))
                 nil)))
       ;; Some errors are sufficiently bewildering that we just fail
       ;; immediately, without trying to recover and compile more of
